==> concepto-bridge-1.2.6.tgz: package/README.md <==
Concepto DSL - Live Mode Bridge
==============================
## SYNOPSIS

This package allows Concepto DSL app to apply realtime changes on a generated native mobile app using its graphical enviroment.

## IMPORTANT

Remember to install tishadow express mode before using this package.

**You need Creador DEV Framework to run this software.**

## UPDATES

version 1.2.4-6:
- Bugfix from version 1.2.2. Missing key at setting socket reconnection to false.

version 1.2.3 :
- Improved speaking new version information.

version 1.2.2 :
- Bugfix. There was an infinite reconnecting to shadow message after being active.

version 1.2.1 :
- Bugfix for re-detecting changes in json properties.

version 1.2.0 :
- Some bugfixes.

version 1.1.6-9 :
- Improved self update notification.

version 1.1.2-5 :
- Added update available notification.

version 1.1.1 :
- Added delete json live_properties on file change to use latest data nodes.

version 1.1.0 :
- Only do audio greeting if there is an app in the current or given directory.

version 1.0.9 :
- Bugfix of audio greeting.

version 1.0.8 :
- Added audio greeting with current app name.

version 1.0.6-7 :
- Added support for meta node '_image' attribute. It gets converted in realtime into base64 and feed to the property handler of the current dsl.

version 1.0.5 :
- Added package version on command line title bin.
- If a Concepto node changes an assigned image, its transformed into a base64 string and sent as a parameter named '_image' to Concepto DSL node properties.
- Now everytime the Live mode is detected on, the 'live' json files are reloaded into memory.

==> concepto-bridge-1.3.4.tgz: package/README.md <==
Concepto DSL - Live Mode Bridge
==============================
## SYNOPSIS

This package allows Concepto DSL app to apply realtime changes on a generated native mobile app using its graphical enviroment.

## IMPORTANT

Remember to install tishadow express mode before using this package.

**You need Creador OPEN Framework to run this software.**

## UPDATES

version 1.3.4:
- Updated location of CreadorOPEN within Apps.

version 1.3.3:
- Double spoken text fix.

version 1.3.2:
- Now respects config.ini of Creador OPEN for not speaking commands.

version 1.3.1:
- Added auto-detection from active diagram on Concepto Live Mode, and reloading.

version 1.3.0:
- Added support for checking if Creador OPEN is installed.
- Added support for multi-language Concepto diagrams.

version 1.2.9:
- Added support for Genymotion and Android.

version 1.2.8:
- Removed some console logging.

version 1.2.7:
- Added support for realtime detection of fontface, fontsize and bold font properties changes.

version 1.2.4-6:
- Bugfix from version 1.2.2. Missing key at setting socket reconnection to false.

version 1.2.3 :
- Improved speaking new version information.

version 1.2.2 :
- Bugfix. There was an infinite reconnecting to shadow message after being active.

version 1.2.1 :
- Bugfix for re-detecting changes in json properties.

version 1.2.0 :
- Some bugfixes.

version 1.1.6-9 :
- Improved self update notification.

version 1.1.2-5 :
- Added update available notification.

version 1.1.1 :
- Added delete json live_properties on file change to use latest data nodes.

version 1.1.0 :
- Only do audio greeting if there is an app in the current or given directory.

version 1.0.9 :
- Bugfix of audio greeting.

version 1.0.8 :
- Added audio greeting with current app name.

version 1.0.6-7 :
- Added support for meta node '_image' attribute. It gets converted in realtime into base64 and feed to the property handler of the current dsl.

version 1.0.5 :
- Added package version on command line title bin.
- If a Concepto node changes an assigned image, its transformed into a base64 string and sent as a parameter named '_image' to Concepto DSL node properties.
- Now everytime the Live mode is detected on, the 'live' json files are reloaded into memory.
